import { world, system, EntityItemComponent, ItemStack, BlockPermutation, Player, Dimension } from "@minecraft/server";
import { positiveEffects, negativeEffects } from "effects.js";

let trinkets_properties_names = [
    "xp_tickler",
    "xp_streamer",
    "xp_torrent",
    "ability_orb",
    "lucky_orb",
    "quarry_orb",
    "health_bounty",
    "on_off_trinket",
    "swift_ring",
    "quick_charm",
    "power_band",
    "shield_ring",
    "leap_charm",
    "blaze_band",
    "aqua_ring",
    "light_charm",
    "health_band",
    "tough_ring",
    "saturate_band",
    "float_charm",
    "slowfall_ring",
    "bargain_charm",
    "smelt_amulet",
    "keep_pendant",
    "vein_amulet",
    "grove_charm",
    "lantern",
    "antidote_band",
    "miner_trinket",
    "explorer_amulet",
    "warrior_pendant",
    "xp_magnet",
];

export function reset_trinkets(player) {
    //player.runCommand('say setDynamicProperty for all trinkets to 0')
    //consumable trinkets
    for (let name of trinkets_properties_names) {
        player.setDynamicProperty(name, 0);
    }
}

//consumable trinkets
world.afterEvents.itemUse.subscribe((event) => {
    const player = event.source;
    //resilience_pendant
    if (event.itemStack.typeId == "ale:resilience_pendant") {
        world.getPlayers().forEach(async (player) => {
            player.addEffect("resistance", 200, { amplifier: 10, showParticles: false });
            player.runCommandAsync("clear @s ale:resilience_pendant 0 1");
            player.runCommandAsync("title @s actionbar §6Resistance X for 10 seconds.");
            player.runCommandAsync("playsound random.burp @s");
        });
    }
    //xp_tickler
    if (event.itemStack.typeId == "ale:xp_tickler" && player.getDynamicProperty("xp_tickler") == 0) {
        player.setDynamicProperty("xp_tickler", 1);
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("clear @s ale:xp_tickler 0 1");
            player.runCommandAsync("title @s actionbar §61 XP every 10 seconds.");
            player.runCommandAsync("playsound random.burp @s");
        });
    } else if (event.itemStack.typeId == "ale:xp_tickler" && player.getDynamicProperty("xp_tickler") == 1) {
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("title @s actionbar §6XP Tickler §ais already active");
        });
    }
    //xp_streamer
    if (event.itemStack.typeId == "ale:xp_streamer" && player.getDynamicProperty("xp_streamer") == 0) {
        player.setDynamicProperty("xp_streamer", 1);
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("clear @s ale:xp_streamer 0 1");
            player.runCommandAsync("title @s actionbar §65 XP every 7 seconds.");
            player.runCommandAsync("playsound random.burp @s");
        });
    } else if (event.itemStack.typeId == "ale:xp_streamer" && player.getDynamicProperty("xp_streamer") == 1) {
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("title @s actionbar §6XP Streamer §ais already active");
        });
    }
    //xp_torrent
    if (event.itemStack.typeId == "ale:xp_torrent" && player.getDynamicProperty("xp_torrent") == 0) {
        player.setDynamicProperty("xp_torrent", 1);
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("clear @s ale:xp_torrent 0 1");
            player.runCommandAsync("title @s actionbar §610 XP every 5 seconds.");
            player.runCommandAsync("playsound random.burp @s");
        });
    } else if (event.itemStack.typeId == "ale:xp_torrent" && player.getDynamicProperty("xp_torrent") == 1) {
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("title @s actionbar §6XP Torrent §ais already active");
        });
    }
    //ability_orb
    if (event.itemStack.typeId == "ale:ability_orb") {
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("clear @s ale:ability_orb 0 1");
            const effect_1 = positiveEffects[Math.floor(Math.random() * positiveEffects.length)];
            const effect_2 = positiveEffects[Math.floor(Math.random() * positiveEffects.length)];
            const effect_3 = negativeEffects[Math.floor(Math.random() * positiveEffects.length)];
            player.addEffect(effect_1, 1200, { showParticles: false });
            player.addEffect(effect_2, 1200, { showParticles: false });
            player.addEffect(effect_3, 1200, { showParticles: false });
            player.runCommandAsync("playsound random.burp @s");
        });
    }
    //lucky_orb
    if (event.itemStack.typeId == "ale:lucky_orb") {
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("clear @s ale:lucky_orb 0 1");
            const effect_1 = positiveEffects[Math.floor(Math.random() * positiveEffects.length)];
            player.addEffect(effect_1, 1200, { showParticles: false });
            player.runCommandAsync("playsound random.burp @s");
        });
    }
    //quarry_orb
    if (event.itemStack.typeId == "ale:quarry_orb") {
        world.getPlayers().forEach(async (player) => {
            player.runCommandAsync("playsound random.burp @s");
            player.runCommandAsync("clear @s ale:quarry_orb 0 1");
            player.runCommandAsync("fill ~-7~-7~-7 ~7~7~7 air replace stone");
            player.runCommandAsync("fill ~-7~-7~-7 ~7~7~7 air replace deepslate");
        });
    }
});

//xp_tickler
system.runInterval(() => {
    world.getPlayers().forEach(async (player) => {
        if (player.getDynamicProperty("xp_tickler") === 1) {
            player.runCommandAsync("xp 1 @s");
        }
    });
}, 200); // 10 seconds

//xp_streamer
system.runInterval(() => {
    world.getPlayers().forEach(async (player) => {
        if (player.getDynamicProperty("xp_streamer") === 1) {
            player.runCommandAsync("xp 5 @s");
        }
    });
}, 140); // 7 seconds

//xp_torrent
system.runInterval(() => {
    world.getPlayers().forEach(async (player) => {
        if (player.getDynamicProperty("xp_torrent") === 1) {
            player.runCommandAsync("xp 10 @s");
        }
    });
}, 100); // 5 seconds



world.afterEvents.itemCompleteUse.subscribe((event) => {
    const player = event.source;
    if (
        (event.itemStack.typeId == "minecraft:apple" ||
            event.itemStack.typeId == "minecraft:carrot" ||
            event.itemStack.typeId == "minecraft:golden_carrot" ||
            event.itemStack.typeId == "minecraft:cooked_chicken" ||
            event.itemStack.typeId == "minecraft:cooked_porkchop" ||
            event.itemStack.typeId == "minecraft:cooked_beef" ||
            event.itemStack.typeId == "minecraft:cooked_mutton" ||
            event.itemStack.typeId == "minecraft:cooked_rabbit" ||
            event.itemStack.typeId == "minecraft:cooked_cod" ||
            event.itemStack.typeId == "minecraft:cooked_salmon" ||
            event.itemStack.typeId == "minecraft:bread" ||
            event.itemStack.typeId == "minecraft:mushroom_stew" ||
            event.itemStack.typeId == "minecraft:beetroot_soup" ||
            event.itemStack.typeId == "minecraft:rabbit_stew" ||
            event.itemStack.typeId == "minecraft:baked_potato" ||
            event.itemStack.typeId == "minecraft:cookie" ||
            event.itemStack.typeId == "minecraft:pumpkin_pie" ||
            event.itemStack.typeId == "minecraft:cake" ||
            event.itemStack.typeId == "minecraft:beetroot" ||
            event.itemStack.typeId == "minecraft:potato" ||
            event.itemStack.typeId == "minecraft:poisonous_potato" ||
            event.itemStack.typeId == "minecraft:golden_apple" ||
            event.itemStack.typeId == "minecraft:enchanted_apple" ||
            event.itemStack.typeId == "minecraft:melon" ||
            event.itemStack.typeId == "minecraft:sweet_berries" ||
            event.itemStack.typeId == "minecraft:chicken" ||
            event.itemStack.typeId == "minecraft:porkchop" ||
            event.itemStack.typeId == "minecraft:beef" ||
            event.itemStack.typeId == "minecraft:mutton" ||
            event.itemStack.typeId == "minecraft:rabbit" ||
            event.itemStack.typeId == "minecraft:cod" ||
            event.itemStack.typeId == "minecraft:salmon" ||
            event.itemStack.typeId == "minecraft:glow_berries" ||
            event.itemStack.typeId == "minecraft:tropical_fish" ||
            event.itemStack.typeId == "minecraft:pufferfish") &&
        player.getDynamicProperty("health_bounty") == 1
    ) {
        const effect_1 = positiveEffects[Math.floor(Math.random() * positiveEffects.length)];
        player.addEffect(effect_1, 100, { showParticles: false });
    }
});

//toggle trinkets
world.afterEvents.itemUse.subscribe((event) => {
    const player = event.source;
    //on_off_trinket
    if (event.itemStack.typeId == "ale:on_off_trinket" && player.getDynamicProperty("on_off_trinket") == 0) {
        player.setDynamicProperty("on_off_trinket", 1);
        player.runCommandAsync("title @s actionbar §6On/Off Trinket: §aON");
        if (player.getDynamicProperty("swift_ring") == 1) {
            player.setDynamicProperty("swift_ring", 3);
        }
        if (player.getDynamicProperty("quick_charm") == 1) {
            player.setDynamicProperty("quick_charm", 3);
        }
        if (player.getDynamicProperty("power_band") == 1) {
            player.setDynamicProperty("power_band", 3);
        }
        if (player.getDynamicProperty("shield_ring") == 1) {
            player.setDynamicProperty("shield_ring", 3);
        }
        if (player.getDynamicProperty("leap_charm") == 1) {
            player.setDynamicProperty("leap_charm", 3);
        }
        if (player.getDynamicProperty("blaze_band") == 1) {
            player.setDynamicProperty("blaze_band", 3);
        }
        if (player.getDynamicProperty("aqua_ring") == 1) {
            player.setDynamicProperty("aqua_ring", 3);
        }
        if (player.getDynamicProperty("light_charm") == 1) {
            player.setDynamicProperty("light_charm", 3);
        }
        if (player.getDynamicProperty("health_band") == 1) {
            player.setDynamicProperty("health_band", 3);
        }
        if (player.getDynamicProperty("tough_ring") == 1) {
            player.setDynamicProperty("tough_ring", 3);
        }
        if (player.getDynamicProperty("saturate_band") == 1) {
            player.setDynamicProperty("saturate_band", 3);
        }
        if (player.getDynamicProperty("float_charm") == 1) {
            player.setDynamicProperty("float_charm", 3);
        }
        if (player.getDynamicProperty("slowfall_ring") == 1) {
            player.setDynamicProperty("slowfall_ring", 3);
        }
        if (player.getDynamicProperty("bargain_charm") == 1) {
            player.setDynamicProperty("bargain_charm", 3);
        }
        if (player.getDynamicProperty("smelt_amulet") == 1) {
            player.setDynamicProperty("smelt_amulet", 3);
        }
        if (player.getDynamicProperty("keep_pendant") == 1) {
            player.setDynamicProperty("keep_pendant", 3);
            world.getPlayers().forEach(async (player) => {
                player.runCommandAsync("gamerule keepinventory false");
            });
        }
        if (player.getDynamicProperty("vein_amulet") == 1) {
            player.setDynamicProperty("vein_amulet", 3);
        }
        if (player.getDynamicProperty("grove_charm") == 1) {
            player.setDynamicProperty("grove_charm", 3);
        }
        if (player.getDynamicProperty("lantern") == 1) {
            player.setDynamicProperty("lantern", 3);
        }
        if (player.getDynamicProperty("antidote") == 1) {
            player.setDynamicProperty("antidote", 3);
        }
        if (player.getDynamicProperty("miner_trinket") == 1) {
            player.setDynamicProperty("miner_trinket", 3);
        }
        if (player.getDynamicProperty("explorer_amulet") == 1) {
            player.setDynamicProperty("explorer_amulet", 3);
        }
        if (player.getDynamicProperty("warrior_pendant") == 1) {
            player.setDynamicProperty("warrior_pendant", 3);
        }
        if (player.getDynamicProperty("xp_magnet") == 1) {
            player.setDynamicProperty("xp_magnet", 3);
        }
        if (player.getDynamicProperty("health_bounty") == 1) {
            player.setDynamicProperty("health_bounty", 3);
        }
    } else if (event.itemStack.typeId == "ale:on_off_trinket" && player.getDynamicProperty("on_off_trinket") == 1) {
        player.setDynamicProperty("on_off_trinket", 0);
        player.runCommandAsync("title @s actionbar §6On/Off Trinket: §cOFF");
        if (player.getDynamicProperty("swift_ring") == 3) {
            player.setDynamicProperty("swift_ring", 1);
        }
        if (player.getDynamicProperty("quick_charm") == 3) {
            player.setDynamicProperty("quick_charm", 1);
        }
        if (player.getDynamicProperty("power_band") == 3) {
            player.setDynamicProperty("power_band", 1);
        }
        if (player.getDynamicProperty("shield_ring") == 3) {
            player.setDynamicProperty("shield_ring", 1);
        }
        if (player.getDynamicProperty("leap_charm") == 3) {
            player.setDynamicProperty("leap_charm", 1);
        }
        if (player.getDynamicProperty("blaze_band") == 3) {
            player.setDynamicProperty("blaze_band", 1);
        }
        if (player.getDynamicProperty("aqua_ring") == 3) {
            player.setDynamicProperty("aqua_ring", 1);
        }
        if (player.getDynamicProperty("light_charm") == 3) {
            player.setDynamicProperty("light_charm", 1);
        }
        if (player.getDynamicProperty("health_band") == 3) {
            player.setDynamicProperty("health_band", 1);
        }
        if (player.getDynamicProperty("tough_ring") == 3) {
            player.setDynamicProperty("tough_ring", 1);
        }
        if (player.getDynamicProperty("saturate_band") == 3) {
            player.setDynamicProperty("saturate_band", 1);
        }
        if (player.getDynamicProperty("float_charm") == 3) {
            player.setDynamicProperty("float_charm", 1);
        }
        if (player.getDynamicProperty("slowfall_ring") == 3) {
            player.setDynamicProperty("slowfall_ring", 1);
        }
        if (player.getDynamicProperty("bargain_charm") == 3) {
            player.setDynamicProperty("bargain_charm", 1);
        }
        if (player.getDynamicProperty("smelt_amulet") == 3) {
            player.setDynamicProperty("smelt_amulet", 1);
        }
        if (player.getDynamicProperty("keep_pendant") == 3) {
            player.setDynamicProperty("keep_pendant", 1);
            world.getPlayers().forEach(async (player) => {
                player.runCommandAsync("gamerule keepinventory true");
            });
        }
        if (player.getDynamicProperty("vein_amulet") == 3) {
            player.setDynamicProperty("vein_amulet", 1);
        }
        if (player.getDynamicProperty("grove_charm") == 3) {
            player.setDynamicProperty("grove_charm", 1);
        }
        if (player.getDynamicProperty("lantern") == 3) {
            player.setDynamicProperty("lantern", 1);
        }
        if (player.getDynamicProperty("antidote") == 3) {
            player.setDynamicProperty("antidote", 1);
        }
        if (player.getDynamicProperty("miner_trinket") == 3) {
            player.setDynamicProperty("miner_trinket", 1);
        }
        if (player.getDynamicProperty("explorer_amulet") == 3) {
            player.setDynamicProperty("explorer_amulet", 1);
        }
        if (player.getDynamicProperty("warrior_pendant") == 3) {
            player.setDynamicProperty("warrior_pendant", 1);
        }
        if (player.getDynamicProperty("xp_magnet") == 3) {
            player.setDynamicProperty("xp_magnet", 1);
        }
        if (player.getDynamicProperty("health_bounty") == 3) {
            player.setDynamicProperty("health_bounty", 1);
        }
    }
    //swift_ring
    if (event.itemStack.typeId == "ale:ringofstormsfury" && player.getDynamicProperty("swift_ring") == 0) {
        player.setDynamicProperty("swift_ring", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Ring of Storms Fury: §aON");
    } else if (event.itemStack.typeId == "ale:ringofstormsfury" && player.getDynamicProperty("swift_ring") == 1) {
        player.setDynamicProperty("swift_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Ring of Storms Fury: §cOFF");
    } else if (event.itemStack.typeId == "ale:ringofstormsfury" && player.getDynamicProperty("swift_ring") == 3) {
        player.setDynamicProperty("swift_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Ring of Storms Fury: §cOFF");
    }
    //quick_charm
    if (event.itemStack.typeId == "ale:arcaneringofmysticism" && player.getDynamicProperty("quick_charm") == 0) {
        player.setDynamicProperty("quick_charm", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Arcane Ring of Mysticism: §aON");
    } else if (event.itemStack.typeId == "ale:arcaneringofmysticism" && player.getDynamicProperty("quick_charm") == 1) {
        player.setDynamicProperty("quick_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Arcane Ring of Mysticism: §cOFF");
    } else if (event.itemStack.typeId == "ale:arcaneringofmysticism" && player.getDynamicProperty("quick_charm") == 3) {
        player.setDynamicProperty("quick_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Arcane Ring of Mysticism: §cOFF");
    }
    //power_band
    if (event.itemStack.typeId == "ale:necklaceofthewarriorswrath" && player.getDynamicProperty("power_band") == 0) {
        player.setDynamicProperty("power_band", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Necklace of the Warriors Wrath: §aON");
    } else if (event.itemStack.typeId == "ale:necklaceofthewarriorswrath" && player.getDynamicProperty("power_band") == 1) {
        player.setDynamicProperty("power_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of the Warriors Wrath: §cOFF");
    } else if (event.itemStack.typeId == "ale:necklaceofthewarriorswrath" && player.getDynamicProperty("power_band") == 3) {
        player.setDynamicProperty("power_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of the Warriors Wrath: §cOFF");
    }
    //shield_ring
    if (event.itemStack.typeId == "ale:titansbastionring" && player.getDynamicProperty("shield_ring") == 0) {
        player.setDynamicProperty("shield_ring", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Titans Bastion Ring: §aON");
    } else if (event.itemStack.typeId == "ale:titansbastionring" && player.getDynamicProperty("shield_ring") == 1) {
        player.setDynamicProperty("shield_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Titans Bastion Ring: §cOFF");
    } else if (event.itemStack.typeId == "ale:titansbastionring" && player.getDynamicProperty("shield_ring") == 3) {
        player.setDynamicProperty("shield_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Titans Bastion Ring: §cOFF");
    }
    //leap_charm
    if (event.itemStack.typeId == "ale:archersemblemnecklace" && player.getDynamicProperty("leap_charm") == 0) {
        player.setDynamicProperty("leap_charm", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Archers Emblem Necklace: §aON");
    } else if (event.itemStack.typeId == "ale:archersemblemnecklace" && player.getDynamicProperty("leap_charm") == 1) {
        player.setDynamicProperty("leap_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Archers Emblem Necklace: §cOFF");
    } else if (event.itemStack.typeId == "ale:archersemblemnecklace" && player.getDynamicProperty("leap_charm") == 3) {
        player.setDynamicProperty("leap_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Archers Emblem Necklace: §cOFF");
    }
    //ringofcrimsonruby
    if (event.itemStack.typeId == "ale:ringofcrimsonruby" && player.getDynamicProperty("blaze_band") == 0) {
        player.setDynamicProperty("blaze_band", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Ring of Crimson Ruby: §aON");
    } else if (event.itemStack.typeId == "ale:ringofcrimsonruby" && player.getDynamicProperty("blaze_band") == 1) {
        player.setDynamicProperty("blaze_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Ring of Crimson Ruby: §cOFF");
    } else if (event.itemStack.typeId == "ale:ringofcrimsonruby" && player.getDynamicProperty("blaze_band") == 3) {
        player.setDynamicProperty("blaze_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Ring of Crimson Ruby: §cOFF");
    }
    //aqua_ring
    if (event.itemStack.typeId == "ale:necklaceofoceansapphire" && player.getDynamicProperty("aqua_ring") == 0) {
        player.setDynamicProperty("aqua_ring", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Ocean Sapphire: §aON");
    } else if (event.itemStack.typeId == "ale:necklaceofoceansapphire" && player.getDynamicProperty("aqua_ring") == 1) {
        player.setDynamicProperty("aqua_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Ocean Sapphire: §cOFF");
    } else if (event.itemStack.typeId == "ale:necklaceofoceansapphire" && player.getDynamicProperty("aqua_ring") == 3) {
        player.setDynamicProperty("aqua_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Ocean Sapphire: §cOFF");
    }
    //light_charm
    if (event.itemStack.typeId == "ale:ringofradiantcitrine" && player.getDynamicProperty("light_charm") == 0) {
        player.setDynamicProperty("light_charm", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Ring of Radiant Citrine: §aON");
    } else if (event.itemStack.typeId == "ale:ringofradiantcitrine" && player.getDynamicProperty("light_charm") == 1) {
        player.setDynamicProperty("light_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Ring of Radiant Citrine: §cOFF");
    } else if (event.itemStack.typeId == "ale:ringofradiantcitrine" && player.getDynamicProperty("light_charm") == 3) {
        player.setDynamicProperty("light_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Ring of Radiant Citrine: §cOFF");
    }
    //health_band
    if (event.itemStack.typeId == "ale:necklaceofcelestialtopaz" && player.getDynamicProperty("health_band") == 0) {
        player.setDynamicProperty("health_band", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Celestial Topaz: §aON");
    } else if (event.itemStack.typeId == "ale:necklaceofcelestialtopaz" && player.getDynamicProperty("health_band") == 1) {
        player.setDynamicProperty("health_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Celestial Topaz: §cOFF");
    } else if (event.itemStack.typeId == "ale:necklaceofcelestialtopaz" && player.getDynamicProperty("health_band") == 3) {
        player.setDynamicProperty("health_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Celestial Topaz: §cOFF");
    }
    //tough_ring
    if (event.itemStack.typeId == "ale:soulboundringofeternity" && player.getDynamicProperty("tough_ring") == 0) {
        player.setDynamicProperty("tough_ring", 1);
        player.addEffect("absorption", 1000, { amplifier: 1, showParticles: false });
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Soulbound Ring of Eternity: §aON");
    } else if (event.itemStack.typeId == "ale:soulboundringofeternity" && player.getDynamicProperty("tough_ring") == 1) {
        player.setDynamicProperty("tough_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Soulbound Ring of Eternity: §cOFF");
    } else if (event.itemStack.typeId == "ale:soulboundringofeternity" && player.getDynamicProperty("tough_ring") == 3) {
        player.setDynamicProperty("tough_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Soulbound Ring of Eternity: §cOFF");
    }
    //saturate_band
    if (event.itemStack.typeId == "ale:necklaceofverdantjade" && player.getDynamicProperty("saturate_band") == 0) {
        player.setDynamicProperty("saturate_band", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Verdant Jade: §aON");
    } else if (event.itemStack.typeId == "ale:necklaceofverdantjade" && player.getDynamicProperty("saturate_band") == 1) {
        player.setDynamicProperty("saturate_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Verdant Jade: §cOFF");
    } else if (event.itemStack.typeId == "ale:necklaceofverdantjade" && player.getDynamicProperty("saturate_band") == 3) {
        player.setDynamicProperty("saturate_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Verdant Jade: §cOFF");
    }
    //float_charm
    if (event.itemStack.typeId == "ale:ringoftwilighttanzanite" && player.getDynamicProperty("float_charm") == 0) {
        player.setDynamicProperty("float_charm", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Ring of Twilight Tanzanite: §aON");
    } else if (event.itemStack.typeId == "ale:ringoftwilighttanzanite" && player.getDynamicProperty("float_charm") == 1) {
        player.setDynamicProperty("float_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Ring of Twilight Tanzanite: §cOFF");
    } else if (event.itemStack.typeId == "ale:ringoftwilighttanzanite" && player.getDynamicProperty("float_charm") == 3) {
        player.setDynamicProperty("float_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Ring of Twilight Tanzanite: §cOFF");
    }
    //slowfall_ring
    if (event.itemStack.typeId == "ale:necklaceoffrozenwinds" && player.getDynamicProperty("slowfall_ring") == 0) {
        player.setDynamicProperty("slowfall_ring", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Frozen Winds: §aON");
    } else if (event.itemStack.typeId == "ale:necklaceoffrozenwinds" && player.getDynamicProperty("slowfall_ring") == 1) {
        player.setDynamicProperty("slowfall_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Frozen Winds: §cOFF");
    } else if (event.itemStack.typeId == "ale:necklaceoffrozenwinds" && player.getDynamicProperty("slowfall_ring") == 3) {
        player.setDynamicProperty("slowfall_ring", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Necklace of Frozen Winds: §cOFF");
    }
    //bargain_charm
    if (event.itemStack.typeId == "ale:bargain_charm" && player.getDynamicProperty("bargain_charm") == 0) {
        player.setDynamicProperty("bargain_charm", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Bargain Charm: §aON");
    } else if (event.itemStack.typeId == "ale:bargain_charm" && player.getDynamicProperty("bargain_charm") == 1) {
        player.setDynamicProperty("bargain_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Bargain Charm: §cOFF");
    } else if (event.itemStack.typeId == "ale:bargain_charm" && player.getDynamicProperty("bargain_charm") == 3) {
        player.setDynamicProperty("bargain_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Bargain Charm: §cOFF");
    }
    //smelt_amulet
    if (event.itemStack.typeId == "ale:smelt_amulet" && player.getDynamicProperty("smelt_amulet") == 0) {
        player.setDynamicProperty("smelt_amulet", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Smelt Amulet: §aON");
    } else if (event.itemStack.typeId == "ale:smelt_amulet" && player.getDynamicProperty("smelt_amulet") == 1) {
        player.setDynamicProperty("smelt_amulet", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Smelt Amulet: §cOFF");
    } else if (event.itemStack.typeId == "ale:smelt_amulet" && player.getDynamicProperty("smelt_amulet") == 3) {
        player.setDynamicProperty("smelt_amulet", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Smelt Amulet: §cOFF");
    }
    //keep_pendant
    if (event.itemStack.typeId == "ale:keep_pendant" && player.getDynamicProperty("keep_pendant") == 0) {
        player.setDynamicProperty("keep_pendant", 1);
        player.runCommandAsync("gamerule keepinventory true");
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Keep Pendant: §aON");

    } else if (event.itemStack.typeId == "ale:keep_pendant" && player.getDynamicProperty("keep_pendant") == 1) {
        player.setDynamicProperty("keep_pendant", 0);
        player.runCommandAsync("gamerule keepinventory false");
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Keep Pendant: §cOFF");
    } else if (event.itemStack.typeId == "ale:keep_pendant" && player.getDynamicProperty("keep_pendant") == 3) {
        player.setDynamicProperty("keep_pendant", 0);
        player.runCommandAsync("gamerule keepinventory false");
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Keep Pendant: §cOFF");
    }
    //vein_amulet
    if (event.itemStack.typeId == "ale:vein_amulet" && player.getDynamicProperty("vein_amulet") == 0) {
        player.setDynamicProperty("vein_amulet", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Vein Miner: §aON");
    } else if (event.itemStack.typeId == "ale:vein_amulet" && player.getDynamicProperty("vein_amulet") == 1) {
        player.setDynamicProperty("vein_amulet", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Vein Miner: §cOFF");
    } else if (event.itemStack.typeId == "ale:vein_amulet" && player.getDynamicProperty("vein_amulet") == 3) {
        player.setDynamicProperty("vein_amulet", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Vein Miner: §cOFF");
    }
    //grove_charm
    if (event.itemStack.typeId == "ale:grove_charm" && player.getDynamicProperty("grove_charm") == 0) {
        player.setDynamicProperty("grove_charm", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Tree Cutter: §aON");
    } else if (event.itemStack.typeId == "ale:grove_charm" && player.getDynamicProperty("grove_charm") == 1) {
        player.setDynamicProperty("grove_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Tree Cutter: §cOFF");
    } else if (event.itemStack.typeId == "ale:grove_charm" && player.getDynamicProperty("grove_charm") == 3) {
        player.setDynamicProperty("grove_charm", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Tree Cutter: §cOFF");
    }
    //lantern
    if (event.itemStack.typeId == "ale:lantern" && player.getDynamicProperty("lantern") == 0) {
        player.setDynamicProperty("lantern", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Torch: §aON");
    } else if (event.itemStack.typeId == "ale:lantern" && player.getDynamicProperty("lantern") == 1) {
        player.setDynamicProperty("lantern", 0);
        player.runCommandAsync("fill ~-3~-3~-3 ~3~3~3 air replace light_block");
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Torch: §cOFF");
    } else if (event.itemStack.typeId == "ale:lantern" && player.getDynamicProperty("lantern") == 3) {
        player.setDynamicProperty("lantern", 0);
        player.runCommandAsync("fill ~-3~-3~-3 ~3~3~3 air replace light_block");
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Torch: §cOFF");
    }
    //antidote_band
    if (event.itemStack.typeId == "ale:antidote_band" && player.getDynamicProperty("antidote_band") == 0) {
        player.setDynamicProperty("antidote_band", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Antidote Band: §aON");
    } else if (event.itemStack.typeId == "ale:antidote_band" && player.getDynamicProperty("antidote_band") == 1) {
        player.setDynamicProperty("antidote_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Antidote Band: §cOFF");
    } else if (event.itemStack.typeId == "ale:antidote_band" && player.getDynamicProperty("antidote_band") == 3) {
        player.setDynamicProperty("antidote_band", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Antidote Band: §cOFF");
    }
    //miner_trinket
    if (event.itemStack.typeId == "ale:miner_trinket" && player.getDynamicProperty("miner_trinket") == 0) {
        player.setDynamicProperty("miner_trinket", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Miner Trinket: §aON");
    } else if (event.itemStack.typeId == "ale:miner_trinket" && player.getDynamicProperty("miner_trinket") == 1) {
        player.setDynamicProperty("miner_trinket", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Miner Trinket: §cOFF");
    } else if (event.itemStack.typeId == "ale:miner_trinket" && player.getDynamicProperty("miner_trinket") == 3) {
        player.setDynamicProperty("miner_trinket", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Miner Trinket: §cOFF");
    }
    //explorer_amulet
    if (event.itemStack.typeId == "ale:explorer_amulet" && player.getDynamicProperty("explorer_amulet") == 0) {
        player.setDynamicProperty("explorer_amulet", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Explorer Amulet: §aON");
    } else if (event.itemStack.typeId == "ale:explorer_amulet" && player.getDynamicProperty("explorer_amulet") == 1) {
        player.setDynamicProperty("explorer_amulet", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Explorer Amulet: §cOFF");
    } else if (event.itemStack.typeId == "ale:explorer_amulet" && player.getDynamicProperty("explorer_amulet") == 3) {
        player.setDynamicProperty("explorer_amulet", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Explorer Amulet: §cOFF");
    }
    //warrior_pendant
    if (event.itemStack.typeId == "ale:warrior_pendant" && player.getDynamicProperty("warrior_pendant") == 0) {
        player.setDynamicProperty("warrior_pendant", 1);
        player.addEffect("strength", 1000, { amplifier: 1, showParticles: false });
        player.addEffect("absorption", 1000, { amplifier: 1, showParticles: false });
        player.addEffect("fire_resistance", 1000, { amplifier: 1, showParticles: false });
        player.addEffect("resistance", 1000, { amplifier: 1, showParticles: false });
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Warrior Pendant: §aON");
    } else if (event.itemStack.typeId == "ale:warrior_pendant" && player.getDynamicProperty("warrior_pendant") == 1) {
        player.setDynamicProperty("warrior_pendant", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Warrior Pendant: §cOFF");
    } else if (event.itemStack.typeId == "ale:warrior_pendant" && player.getDynamicProperty("warrior_pendant") == 3) {
        player.setDynamicProperty("warrior_pendant", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Warrior Pendant: §cOFF");
    }
    //xp_magnet
    if (event.itemStack.typeId == "ale:xp_magnet" && player.getDynamicProperty("xp_magnet") == 0) {
        player.setDynamicProperty("xp_magnet", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6XP Magnet: §aON");
    } else if (event.itemStack.typeId == "ale:xp_magnet" && player.getDynamicProperty("xp_magnet") == 1) {
        player.setDynamicProperty("xp_magnet", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6XP Magnet: §cOFF");
    } else if (event.itemStack.typeId == "ale:xp_magnet" && player.getDynamicProperty("xp_magnet") == 3) {
        player.setDynamicProperty("xp_magnet", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6XP Magnet: §cOFF");
    }
    //health_bounty
    if (event.itemStack.typeId == "ale:health_bounty" && player.getDynamicProperty("health_bounty") == 0) {
        player.setDynamicProperty("health_bounty", 1);
        player.runCommandAsync("playsound random.pop @s");
        player.runCommandAsync("title @s actionbar §6Health Bounty: §aON");
    } else if (event.itemStack.typeId == "ale:health_bounty" && player.getDynamicProperty("health_bounty") == 1) {
        player.setDynamicProperty("health_bounty", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Health Bounty: §cOFF");
    } else if (event.itemStack.typeId == "ale:health_bounty" && player.getDynamicProperty("health_bounty") == 3) {
        player.setDynamicProperty("health_bounty", 0);
        player.runCommandAsync("playsound random.pop2 @s");
        player.runCommandAsync("title @s actionbar §6Health Bounty: §cOFF");
    }
});

system.runInterval(() => {
    world.getPlayers().forEach(async (player) => {
        //swift_ring
        if (player.getDynamicProperty("swift_ring") == 1) {
            player.addEffect("speed", 220, { amplifier: 0, showParticles: false });
        }
        //quick_charm
        if (player.getDynamicProperty("quick_charm") == 1) {
            player.addEffect("haste", 220, { amplifier: 0, showParticles: false });
        }
        //power_band
        if (player.getDynamicProperty("power_band") == 1) {
            player.addEffect("strength", 220, { amplifier: 0, showParticles: false });
        }
        //shield_ring
        if (player.getDynamicProperty("shield_ring") == 1) {
            player.addEffect("resistance", 220, { amplifier: 0, showParticles: false });
        }
        //leap_charm
        if (player.getDynamicProperty("leap_charm") == 1) {
            player.addEffect("jump_boost", 220, { amplifier: 0, showParticles: false });
        }
        //blaze_band
        if (player.getDynamicProperty("blaze_band") == 1) {
            player.addEffect("fire_resistance", 220, { amplifier: 0, showParticles: false });
        }
        //aqua_ring
        if (player.getDynamicProperty("aqua_ring") == 1) {
            player.addEffect("water_breathing", 220, { amplifier: 0, showParticles: false });
        }
        //light_charm
        if (player.getDynamicProperty("light_charm") == 1) {
            player.addEffect("night_vision", 220, { amplifier: 0, showParticles: false });
        }
        //health_band
        if (player.getDynamicProperty("health_band") == 1) {
            player.addEffect("health_boost", 220, { amplifier: 0, showParticles: false });
        }
        //saturate_band
        if (player.getDynamicProperty("saturate_band") == 1) {
            player.addEffect("saturation", 220, { amplifier: 0, showParticles: false });
        }
        //float_charm
        if (player.getDynamicProperty("float_charm") == 1) {
            player.addEffect("levitation", 220, { amplifier: 0, showParticles: false });
        }
        //slowfall_ring
        if (player.getDynamicProperty("slowfall_ring") == 1) {
            player.addEffect("slow_falling", 220, { amplifier: 0, showParticles: false });
        }
        //bargain_charm
        if (player.getDynamicProperty("bargain_charm") == 1) {
            player.addEffect("village_hero", 220, { amplifier: 0, showParticles: false });
        }
        //lantern
        if (player.getDynamicProperty("lantern") == 1) {
            player.runCommandAsync("function lantern");
        }
        //antidote_band
        if (player.getDynamicProperty("antidote_band") == 1) {
            player.removeEffect("poison");
        }
        //miner_trinket
        if (player.getDynamicProperty("miner_trinket") == 1) {
            player.addEffect("haste", 220, { amplifier: 1, showParticles: false });
            player.addEffect("night_vision", 220, { amplifier: 1, showParticles: false });
            player.addEffect("saturation", 220, { amplifier: 1, showParticles: false });
        }
        //explorer_amulet
        if (player.getDynamicProperty("explorer_amulet") == 1) {
            player.addEffect("speed", 220, { amplifier: 1, showParticles: false });
            player.addEffect("water_breathing", 220, { amplifier: 1, showParticles: false });
            player.addEffect("jump_boost", 220, { amplifier: 1, showParticles: false });
            player.addEffect("slow_falling", 220, { amplifier: 1, showParticles: false });
        }
        //xp_magnet
        if (player.getDynamicProperty("xp_magnet") == 1) {
            player.runCommandAsync(`execute as @e[type=item,rm=0.5,r=16] at @s facing entity @p feet run tp ^^^0.3`);
            player.runCommandAsync(`execute as @e[type=xp_orb,rm=0.5,r=16] at @s facing entity @p feet run tp ^^^0.3`);
        }
    });
});

system.runInterval(() => {
    world.getPlayers().forEach(async (player) => {
        //warrior_pendant
        if (player.getDynamicProperty("warrior_pendant") == 1) {
            player.addEffect("strength", 1000, { amplifier: 1, showParticles: false });
            player.addEffect("absorption", 1000, { amplifier: 1, showParticles: false });
            player.addEffect("fire_resistance", 1000, { amplifier: 1, showParticles: false });
            player.addEffect("resistance", 1000, { amplifier: 1, showParticles: false });
        }
    });
}, 900);
system.runInterval(() => {
    world.getPlayers().forEach(async (player) => {
        //tough_ring
        if (player.getDynamicProperty("tough_ring") == 1) {
            player.addEffect("absorption", 1000, { amplifier: 0, showParticles: false });
        }
    });
}, 900);

//smelt_amulet
const smelt_amulet_blocks = new Map(
    [
        ["minecraft:gold_ore", "minecraft:gold_ingot"],
        ["minecraft:iron_ore", "minecraft:iron_ingot"],
        ["minecraft:copper_ore", "minecraft:copper_ingot"],
        ["minecraft:deepslate_gold_ore", "minecraft:gold_ingot"],
        ["minecraft:deepslate_iron_ore", "minecraft:iron_ingot"],
        ["minecraft:deepslate_copper_ore", "minecraft:copper_ingot"],
    ].map(([block, item]) => [BlockPermutation.resolve(block), item])
);

world.beforeEvents.playerBreakBlock.subscribe((event) => {
    const block = event.block;
    const item = smelt_amulet_blocks.get(block.permutation);
    const { x, y, z } = block.location;
    world.getPlayers().forEach(async (player) => {
        if (smelt_amulet_blocks.has(block.permutation) && !player.isSneaking && player.getDynamicProperty("smelt_amulet") == 1) {
            event.cancel = true;
            system.run(() => {
                block.dimension.spawnItem(new ItemStack(item), block.location);
                block.dimension.runCommand(`setblock ${x} ${y} ${z} air`);
            });
        }
    });
});

////vein_amulet
const vein_amulet_blocks = new Set(
    [
        "minecraft:coal_ore",
        "minecraft:gold_ore",
        "minecraft:iron_ore",
        "minecraft:lapis_ore",
        "minecraft:copper_ore",
        "minecraft:quartz_ore",
        "minecraft:diamond_ore",
        "minecraft:emerald_ore",
        "minecraft:redstone_ore",
        "minecraft:lit_redstone_ore",
        "minecraft:nether_gold_ore",
        "minecraft:deepslate_coal_ore",
        "minecraft:deepslate_gold_ore",
        "minecraft:deepslate_iron_ore",
        "minecraft:deepslate_lapis_ore",
        "minecraft:deepslate_copper_ore",
        "minecraft:deepslate_diamond_ore",
        "minecraft:deepslate_emerald_ore",
        "minecraft:deepslate_redstone_ore",
        "minecraft:lit_deepslate_redstone_ore",
    ].map((id) => BlockPermutation.resolve(id))
);

world.beforeEvents.playerBreakBlock.subscribe((event) => {
    const block = event.block;
    const { x, y, z } = block.location;
    world.getPlayers().forEach(async (player) => {
        if (vein_amulet_blocks.has(block.permutation) && player.isSneaking && player.getDynamicProperty("vein_amulet") == 1) {
            player.runCommandAsync(`execute positioned ${x} ${y} ${z} run function vein_amulet`);
        }
    });
});

//grove_charm
const grove_charm_blocks = new Set(
    [
        "minecraft:acacia_log",
        "minecraft:birch_log",
        "minecraft:cherry_log",
        "minecraft:dark_oak_log",
        "minecraft:jungle_log",
        "minecraft:mangrove_log",
        "minecraft:oak_log",
        "minecraft:spruce_log",
        "minecraft:stripped_acacia_log",
        "minecraft:stripped_birch_log",
        "minecraft:stripped_cherry_log",
        "minecraft:stripped_dark_oak_log",
        "minecraft:stripped_jungle_log",
        "minecraft:stripped_mangrove_log",
        "minecraft:stripped_oak_log",
        "minecraft:stripped_spruce_log",
        "minecraft:wood",
    ].map((id) => BlockPermutation.resolve(id))
);

world.beforeEvents.playerBreakBlock.subscribe((event) => {
    const block = event.block;
    const { x, y, z } = block.location;
    world.getPlayers().forEach(async (player) => {
        if (grove_charm_blocks.has(block.permutation) && player.getDynamicProperty("grove_charm") == 1) {
            player.runCommandAsync(`execute positioned ${x} ${y} ${z} run function grove_charm`);
        }
    });
});
